#!/usr/bin/env tclsh

set dbfile /home/yourbot/eggdrop/topics.db ;# edit this

# Copyright (c) 2014, Moritz Wilhelmy (ente on IRCnet)
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

set start_time [clock milliseconds]

package require sqlite3
package require html
package require ncgi

# Edit this if you want a different format for date/timestamps
# Or if you want a different timezone than GMT/UTC because your channel is
# local.
proc datetime {sec {time 1}} {
	if $time {
		clock format $sec -format "%Y-%m-%d&nbsp;%R" -gmt 1
	} else {
		clock format $sec -format "%Y-%m-%d" -gmt 1
	}
}

interp alias {} sanitize {} html::html_entities

proc % {args} {
	if {[llength $args]==0} {
		puts [html::closeTag]
	} else {
		puts [html::openTag {*}$args] 
	}
}

proc authfail {} {
	ncgi::redirect .
	exit
}

ncgi::parse

set channel [ncgi::value channel]

sqlite3 db $dbfile
proc footer {} {
	set now [clock milliseconds]

	% small style=\"color:#aaa\"
		puts "Page generated in [expr {$now-$::start_time}] ms by usertopic.tcl"
	%

	puts [html::end]
}

ncgi::header "text/html; charset=utf-8"
puts "<!DOCTYPE html>"

html::init

html::headTag {link href="table.css" rel="stylesheet" type="text/css"}
html::headTag {link href="main.css" rel="stylesheet" type="text/css"}

puts [html::head "Tard's topics"]
puts [html::bodyTag]

if {$channel != ""} {
	puts [html::h1 "Tard's topics for $channel"]
} else {
	puts [html::h1 "Tard's topics"]
}

% table
	% thead
		% tr
		foreach v {"ID" "Topic" "by"} {
			% th
				puts $v
			%
		
		}
		if {$channel == ""} {
			% th
				puts "channel"
			%
		}
			% th style=\"text-align:right\"
				puts "date"
			%
		%
	%
	% tbody



set where-clause ""
if {$channel != ""} {
	set where-clause "WHERE chan = :channel"
}

set sql "select *,COALESCE(egg_handle,nick) AS nick FROM topics ${where-clause} ORDER BY seq DESC"

db eval $sql {
	% tr
		% td style=\"text-align:right\"
			puts $seq
		%
		% td
		regsub -all {(https?://|www\.|[a-z0-9\-]+\.[a-z]{2,4}/)\S+} [sanitize $topic] {<a href="&">&</a>} topic
		puts $topic
		%
		% td
			puts [sanitize $nick]
		%
		if {$channel == ""} {
		% td
			puts [sanitize $chan]
		%
		}
		% td
			puts [datetime $ts]
		%
	%
}

%

% ;# table

footer


# $Id: topics.cgi,v 1.3 2014/07/13 14:46:37 eggderp Exp eggderp $
